@@ -50,7 +50,7 @@ LOGGER = logging.getLogger(LOGGER_BASENAME)
 LOGGER.addHandler(logging.NullHandler())
 
 
-class ZoneEnergyLabelingData:  # pylint: disable=too-few-public-methods
+class ZoneEnergyLabelingData:
     """Models the data for energy labeling to export."""
 
     def __init__(self, filename, name, energy_label):
@@ -66,7 +66,7 @@ class ZoneEnergyLabelingData:  # pylint: disable=too-few-public-methods
                           indent=2, default=str)
 
 
-class SecurityHubFindingsData:  # pylint: disable=too-few-public-methods
+class SecurityHubFindingsData:
     """Models the data for energy labeling to export."""
 
     def __init__(self, filename, security_hub_findings):
@@ -98,7 +98,7 @@ class SecurityHubFindingsData:  # pylint: disable=too-few-public-methods
                            for finding in self._security_hub_findings], indent=2, default=str)
 
 
-class SecurityHubFindingsResourcesData:  # pylint: disable=too-few-public-methods
+class SecurityHubFindingsResourcesData:
     """Models the data for energy labeling to export."""
 
     def __init__(self, filename, security_hub_findings):
@@ -117,7 +117,7 @@ class SecurityHubFindingsResourcesData:  # pylint: disable=too-few-public-method
                           indent=2, default=str)
 
 
-class SecurityHubFindingsTypesData:  # pylint: disable=too-few-public-methods
+class SecurityHubFindingsTypesData:
     """Models the data for energy labeling to export."""
 
     def __init__(self, filename, security_hub_findings):
@@ -145,8 +145,8 @@ class LabeledAccountData:
         """Data of an account to export."""
         return {'Account ID': self._labeled_account.id,
                 'Account Name (or alias if set)': self._labeled_account.alias or self._labeled_account.name,
-                'Number of critical & high findings':
-                    self._labeled_account.energy_label.number_of_critical_high_findings,
+                'Number of critical findings': self._labeled_account.energy_label.number_of_critical_findings,
+                'Number of high findings': self._labeled_account.energy_label.number_of_high_findings,
                 'Number of medium findings': self._labeled_account.energy_label.number_of_medium_findings,
                 'Number of low findings': self._labeled_account.energy_label.number_of_low_findings,
                 'Number of maximum days open': self._labeled_account.energy_label.max_days_open,
@@ -158,7 +158,7 @@ class LabeledAccountData:
         return json.dumps(self.data, indent=2, default=str)
 
 
-class LabeledAccountsData:  # pylint: disable=too-few-public-methods
+class LabeledAccountsData:
     """Models the data for energy labeling to export."""
 
     def __init__(self, filename, labeled_accounts):
@@ -170,3 +170,16 @@ class LabeledAccountsData:  # pylint: disable=too-few-public-methods
         """Data to json."""
         return json.dumps([LabeledAccountData(self.filename, account).data
                            for account in self._labeled_accounts], indent=2, default=str)
+
+
+class Metadata:
+    """Models the data for execution metadata to export."""
+
+    def __init__(self, filename, metadata):
+        self.filename = filename
+        self._metadata = metadata
+
+    @property
+    def json(self):
+        """Data to json."""
+        return json.dumps(self._metadata, indent=2, default=str)
