@@ -80,7 +80,7 @@ LOGGER = logging.getLogger(LOGGER_BASENAME)
 LOGGER.addHandler(logging.NullHandler())
 
 
-class Zone(ABC):  # pylint: disable=too-many-instance-attributes
+class Zone(ABC):
     """Models the zone and retrieves accounts from it."""
 
     def __init__(self,  # pylint: disable=too-many-arguments,dangerous-default-value
@@ -353,7 +353,7 @@ class AuditZone(Zone):
         """
         try:
             config = Config(region_name=region)
-            kwargs = dict(config=config)
+            kwargs = {"config": config}
             client = boto3.client('securityhub', **kwargs)
             client.describe_hub()
         except (client.exceptions.InvalidAccessException,  # noqa
@@ -429,12 +429,11 @@ class AwsAccount:
                 open_days_counter[finding.days_open] += 1
         if not counted_findings:
             self._logger.info(f'No findings for account {self.id}')
-            self.energy_label = AccountEnergyLabel('A', 0, 0, 0, 0)
+            self.energy_label = AccountEnergyLabel('A', 0, 0, 0, 0, 0)
             return self.energy_label
         try:
             number_of_critical_findings = counted_findings.get('CRITICAL', 0)
             number_of_high_findings = counted_findings.get('HIGH', 0)
-            number_of_critical_high_findings = number_of_critical_findings + number_of_high_findings
             number_of_medium_findings = counted_findings.get('MEDIUM', 0)
             number_of_low_findings = counted_findings.get('LOW', 0)
             try:
@@ -442,19 +441,20 @@ class AwsAccount:
             except ValueError:
                 max_days_open = 0
             self._logger.debug(f'Calculating for account {self.id} '
-                               f'with number of critical+high findings '
-                               f'{number_of_critical_high_findings}, '
+                               f'with number of critical findings {number_of_critical_findings},'
+                               f'number of high findings {number_of_high_findings}, '
                                f'number of medium findings {number_of_medium_findings}, '
                                f'number of low findings {number_of_low_findings}, '
                                f'and findings have been open for over '
                                f'{max_days_open} days')
             for threshold in self.account_thresholds:
-                if all([number_of_critical_high_findings <= threshold['critical_high'],
+                if all([(number_of_critical_findings + number_of_high_findings) <= threshold['critical_high'],
                         number_of_medium_findings <= threshold['medium'],
                         number_of_low_findings <= threshold['low'],
                         max_days_open < threshold['days_open_less_than']]):
                     self.energy_label = AccountEnergyLabel(threshold['label'],
-                                                           number_of_critical_high_findings,
+                                                           number_of_critical_findings,
+                                                           number_of_high_findings,
                                                            number_of_medium_findings,
                                                            number_of_low_findings,
                                                            max_days_open)
@@ -464,17 +464,18 @@ class AwsAccount:
             else:
                 self._logger.debug('No match with thresholds for energy label, using default worst one.')
                 self.energy_label = AccountEnergyLabel('F',
-                                                       number_of_critical_high_findings,
+                                                       number_of_critical_findings,
+                                                       number_of_high_findings,
                                                        number_of_medium_findings,
                                                        number_of_low_findings,
                                                        max_days_open)
         except Exception:  # pylint: disable=broad-except
-            self._logger.exception(f'Could not calculate energy label for account {self.id}, using the default "F"')
+            self._logger.warning(f'Could not calculate energy label for account {self.id}, using the default "F"')
         return self.energy_label
 
 
 @dataclass
-class Finding:  # pylint: disable=too-many-public-methods
+class Finding:
     """Models a finding."""
 
     _data: dict
@@ -570,7 +571,7 @@ class Finding:  # pylint: disable=too-many-public-methods
     @property
     def is_cis(self):
         """Is this cis framework finding."""
-        return '/cis-aws' in self.generator_id
+        return 'cis-aws' in self.generator_id
 
     @property
     def is_pci_dss(self):
@@ -707,7 +708,7 @@ class SecurityHub:
     def _get_security_hub_client(region):
         try:
             config = Config(region_name=region)
-            kwargs = dict(config=config)
+            kwargs = {"config": config}
             client = boto3.client('securityhub', **kwargs)
         except (botocore.exceptions.NoRegionError,
                 botocore.exceptions.InvalidRegionError) as msg:
@@ -719,7 +720,7 @@ class SecurityHub:
         kwargs = {}
         if region:
             config = Config(region_name=region)
-            kwargs = dict(config=config)
+            kwargs = {"config": config}
         try:
             client = boto3.client('ec2', **kwargs)
             client.describe_regions()
@@ -807,7 +808,7 @@ class SecurityHub:
 
         attributes = [framework_to_finding_attribute(framework) for framework in frameworks]
         return [finding for finding in findings
-                if any([getattr(finding, attribute) for attribute in attributes])]
+                if any(getattr(finding, attribute) for attribute in attributes)]
 
     def get_findings(self, query_filter):
         """Retrieves findings from security hub based on a provided query.
@@ -932,16 +933,17 @@ class SecurityHub:
         return client.list_enabled_products_for_import().get('ProductSubscriptions', [])
 
 
-class DataExporter:  # pylint: disable=too-few-public-methods
+class DataExporter:
     """Export AWS security data."""
 
     #  pylint: disable=too-many-arguments
-    def __init__(self, export_types, name, energy_label, security_hub_findings, labeled_accounts):
+    def __init__(self, export_types, name, energy_label, security_hub_findings, labeled_accounts, metadata):
         self.name = name
         self.energy_label = energy_label
         self.security_hub_findings = security_hub_findings
         self.labeled_accounts = labeled_accounts
         self.export_types = export_types
+        self.metadata = metadata
         self._logger = logging.getLogger(f'{LOGGER_BASENAME}.{self.__class__.__name__}')
 
     def export(self, path):
@@ -954,7 +956,8 @@ class DataExporter:  # pylint: disable=too-few-public-methods
                                         self.name,
                                         self.energy_label,
                                         self.security_hub_findings,
-                                        self.labeled_accounts)
+                                        self.labeled_accounts,
+                                        self.metadata)
             if destination.type == 's3':
                 self._export_to_s3(path, data_file.filename, data_file.json)  # pylint: disable=no-member
             else:
@@ -967,7 +970,7 @@ class DataExporter:  # pylint: disable=too-few-public-methods
             path.mkdir()
         except FileExistsError:
             self._logger.debug(f'Directory {directory} already exists.')
-        with open(path.joinpath(filename), 'w') as jsonfile:
+        with open(path.joinpath(filename), 'w', encoding='utf-8') as jsonfile:
             jsonfile.write(data)
         self._logger.info(f'File {filename} copied to {directory}')
 
@@ -986,11 +989,11 @@ class DataExporter:  # pylint: disable=too-few-public-methods
         self._logger.info(f'File {filename} copied to {s3_url}')
 
 
-class DataFileFactory:  # pylint: disable=too-few-public-methods
+class DataFileFactory:
     """Data export factory to handle the different data types returned."""
 
     #  pylint: disable=too-many-arguments, unused-argument
-    def __new__(cls, export_type, name, energy_label, security_hub_findings, labeled_accounts):
+    def __new__(cls, export_type, name, energy_label, security_hub_findings, labeled_accounts, metadata):
         data_file_configuration = next((datafile for datafile in FILE_EXPORT_TYPES
                                         if datafile.get('type') == export_type.lower()), None)
 
